===================================================
Plette: Structured Pipfile and Pipfile.lock models.
===================================================

Plette implements Pipfle and Pipfile.lock parsers, generators, and optional
validators to let the user work with them in a structured manner.


Installation
============

Install with pip::

    pip install plette

Install with the optional validation feature::

    pip install plette[validation]
